@@ -7,6 +7,8 @@ from pathlib import Path
 from typing import Union
 
 import requests
+import sys
+import time
 
 # module‐level caches
 _cached_server_url: str = None
@@ -17,18 +19,15 @@ def _is_running_in_k8s() -> bool:
     if _is_k8s is not None:
         return _is_k8s
 
-    # روش سریع: متغیر محیطی
     if os.getenv("KUBERNETES_SERVICE_HOST"):
         _is_k8s = True
         return _is_k8s
 
-    # ServiceAccount Token
     token = Path('/var/run/secrets/kubernetes.io/serviceaccount/token')
     if token.exists():
         _is_k8s = True
         return _is_k8s
 
-    # cgroup
     try:
         with open('/proc/1/cgroup') as f:
             if 'kubepods' in f.read():
@@ -37,7 +36,6 @@ def _is_running_in_k8s() -> bool:
     except Exception:
         pass
 
-    # DNS lookup
     try:
         socket.gethostbyname('kubernetes.default.svc.cluster.local')
         _is_k8s = True
@@ -51,7 +49,6 @@ def _get_server_url() -> str:
     if _cached_server_url:
         return _cached_server_url
 
-    # allow override via env
     override = os.getenv('WATCHLOG_AGENT_URL')
     if override:
         _cached_server_url = override.rstrip('/')
@@ -72,18 +69,24 @@ class Watchlog:
         If not provided, will auto-detect or use WATCHLOG_AGENT_URL.
         """
         self.base_url = (url or _get_server_url()).rstrip('/')
+        # لاگ مقدار نهایی URL
+        print(f"[Watchlog DEBUG] initialized with base_url = {self.base_url}", flush=True)
 
     def _request(self, full_url: str) -> None:
         try:
-            requests.get(full_url, timeout=1)
-        except Exception:
-            # silent failure
-            pass
+            print(f"[Watchlog DEBUG] sending HTTP GET to {full_url}", flush=True)
+            resp = requests.get(full_url, timeout=1)
+            print(f"[Watchlog DEBUG] response status: {resp.status_code}", flush=True)
+        except Exception as e:
+            # لاگ خطا
+            print(f"[Watchlog ERROR] request to {full_url!r} failed: {e}", flush=True)
 
     def _send_metric(self, method: str, metric: str, value: Union[int, float]) -> None:
         if not isinstance(metric, str) or not metric:
+            print(f"[Watchlog WARN] invalid metric name: {metric!r}", flush=True)
             return
         if not isinstance(value, (int, float)):
+            print(f"[Watchlog WARN] invalid metric value: {value!r}", flush=True)
             return
 
         qs = {
@@ -92,7 +95,8 @@ class Watchlog:
             'value': value
         }
         url = f"{self.base_url}?{requests.utils.requote_uri(requests.compat.urlencode(qs))}"
-        # fire-and-forget
+        # لاگ قبل از ساخت Thread
+        print(f"[Watchlog DEBUG] spawning thread for metric: {method} {metric}={value}", flush=True)
         threading.Thread(target=self._request, args=(url,), daemon=True).start()
 
     def increment(self, metric: str, value: Union[int, float] = 1) -> None:
@@ -112,11 +116,15 @@ class Watchlog:
     def percentage(self, metric: str, value: Union[int, float]) -> None:
         if 0 <= value <= 100:
             self._send_metric('percentage', metric, value)
+        else:
+            print(f"[Watchlog WARN] percentage out of range: {value}", flush=True)
 
     def systembyte(self, metric: str, value: Union[int, float]) -> None:
         if value > 0:
             self._send_metric('systembyte', metric, value)
+        else:
+            print(f"[Watchlog WARN] systembyte must be >0: {value}", flush=True)
 
 
-# singleton instance, like the Node.js module.exports = new SocketCli();
+# singleton instance
 watchlog = Watchlog()
